Coverage report

File | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
/var/devmt/py/dbilib_0.4.1/dbilib/__init__.py | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_base.py | 54 | 0 | 21 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_mysql.py | 61 | 0 | 12 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_dbi_sqlite.py | 17 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/_version.py | 1 | 0 | 0 | 100%
/var/devmt/py/dbilib_0.4.1/dbilib/database.py | 25 | 0 | 5 | 100%
Total | 159 | 0 | 38 | 100%

No items found using the specified filter.